@@ -3,7 +3,7 @@
 
 # Packgage library and global options
 .onLoad <- function(libname, pkgname) {
-  library.dynam("bigalgebra", pkgname, libname);
+#  library.dynam("bigalgebra", pkgname, libname);
   options(bigalgebra.temp_pattern="matrix_")
   options(bigalgebra.mixed_arithmetic_returns_R_matrix=TRUE)
   options(bigalgebra.tempdir=tempdir)
@@ -11,7 +11,7 @@
 }
 
 .onUnload <- function(libpath) {
-  library.dynam.unload("bigalgebra", libpath);
+#  library.dynam.unload("bigalgebra", libpath);
   options(bigalgebra.temp_pattern=c())
   options(bigalgebra.mixed_arithmetic_returns_R_matrix=c())
   options(bigalgebra.tempdir=c())
